@@ -1,7 +1,6 @@
 import logging
 from abc import ABC, abstractmethod
-from dataclasses import dataclass
-from dataclasses import field
+from attrs import define, field
 from functools import cached_property
 from tempfile import TemporaryDirectory
 from textwrap import dedent
@@ -9,7 +8,7 @@ from threading import RLock
 from typing import ClassVar, TypeVar, Any, Callable
 from typing import List, Type, Optional, Tuple, Dict
 
-import jsons
+from resotolib.json import to_json as to_js, from_json as from_js
 from kubernetes.client import ApiClient, Configuration, ApiException
 from kubernetes.config import load_kube_config, list_kube_config_contexts
 
@@ -18,14 +17,15 @@ from resotolib.config import Config
 from resotolib.graph import Graph
 from resotolib.json_bender import S, bend, Bender, Sort, AsDate
 from resotolib.types import Json
-from resotolib.utils import num_default_threads, rnd_str
+from resotolib.proc import num_default_threads
+from resotolib.utils import rnd_str
 
 log = logging.getLogger("resoto.plugins.k8s")
 
 SortTransitionTime = Sort(S("lastTransitionTime") >> AsDate())
 
 
-@dataclass(eq=False)
+@define(eq=False, slots=False)
 class KubernetesResource(BaseResource):
     kind: ClassVar[str] = "kubernetes_resource"
 
@@ -42,18 +42,16 @@ class KubernetesResource(BaseResource):
 
     resource_version: Optional[str] = None
     namespace: Optional[str] = None
-    labels: Dict[str, str] = field(default_factory=dict)
+    labels: Dict[str, str] = field(factory=dict)
 
     def to_json(self) -> Json:
-        return jsons.dump(  # type: ignore
+        return to_js(
             self,
-            strip_privates=True,
-            strip_nulls=True,
             strip_attr=(
                 "k8s_name",
                 "mapping",
                 "phantom",
-                "successor_kinds",
+                "reference_kinds",
                 "parent_resource",
                 "usage_percentage",
                 "dname",
@@ -69,7 +67,6 @@ class KubernetesResource(BaseResource):
                 "clean",
                 "cleaned",
                 "protected",
-                "_graph",
                 "graph",
                 "max_graph_depth",
                 "resource_type",
@@ -87,7 +84,7 @@ class KubernetesResource(BaseResource):
     @classmethod
     def from_json(cls: Type["KubernetesResource"], json: Json) -> "KubernetesResource":
         mapped = bend(cls.mapping, json)
-        return jsons.load(mapped, cls)  # type: ignore
+        return from_js(mapped, cls)
 
     @classmethod
     def k8s_name(cls: Type["KubernetesResource"]) -> str:
@@ -134,7 +131,7 @@ class KubernetesResource(BaseResource):
 KubernetesResourceType = TypeVar("KubernetesResourceType", bound=KubernetesResource)
 
 
-@dataclass
+@define
 class K8sAccess:
     kind: ClassVar[str] = "k8s_access"
     name: str = field(metadata={"description": "The name of the kubernetes cluster."})
@@ -171,12 +168,12 @@ class K8sAccess:
         )
 
 
-@dataclass
+@define
 class K8sConfigFile:
     kind: ClassVar[str] = "k8s_config_file"
     path: str = field(metadata={"description": "Path to the kubeconfig file."})
     contexts: List[str] = field(
-        default_factory=list,
+        factory=list,
         metadata={
             "description": "The contexts to use in the specified config file.\n"
             "You can also set all_contexts to true to use all contexts."
@@ -188,11 +185,11 @@ class K8sConfigFile:
     )
 
 
-@dataclass
+@define(slots=False)
 class K8sConfig:
     kind: ClassVar[str] = "k8s"
     configs: List[K8sAccess] = field(
-        default_factory=list,
+        factory=list,
         metadata={
             "description": dedent(
                 """
@@ -207,7 +204,7 @@ class K8sConfig:
         },
     )
     config_files: List[K8sConfigFile] = field(
-        default_factory=list,
+        factory=list,
         metadata={
             "description": dedent(
                 """
@@ -222,15 +219,15 @@ class K8sConfig:
     )
 
     collect: List[str] = field(
-        default_factory=list,
+        factory=list,
         metadata={"description": "Objects to collect (default: all)"},
     )
     no_collect: List[str] = field(
-        default_factory=list,
+        factory=list,
         metadata={"description": "Objects to exclude (default: none)"},
     )
     pool_size: int = field(
-        default_factory=num_default_threads,
+        factory=num_default_threads,
         metadata={"description": "Thread/process pool size"},
     )
     fork_process: bool = field(
@@ -240,7 +237,7 @@ class K8sConfig:
 
     _clients: Optional[Dict[str, "K8sClient"]] = None
     _temp_dir: Optional[TemporaryDirectory[str]] = None
-    _lock: RLock = field(default_factory=RLock)
+    _lock: RLock = field(factory=RLock)
 
     def __getstate__(self) -> Dict[str, Any]:
         d = self.__dict__.copy()
@@ -334,10 +331,10 @@ class K8sConfig:
                 fork_process=json.get("fork_process", False),
             )
         else:
-            return jsons.load(json, K8sConfig)  # type: ignore
+            return from_js(json, K8sConfig)
 
 
-@dataclass
+@define
 class K8sApiResource:
     base: str
     name: str
